summaryrefslogtreecommitdiff
path: root/src/lib/butler.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2021-09-15 23:36:21 +0200
committerCarl Hetherington <cth@carlh.net>2021-09-27 13:41:46 +0200
commit3799e91d126d243d41c44dcb0ca1bfa66b53a57e (patch)
tree74348b18d5ac0ef81bbebb27fe32862b22baa0b2 /src/lib/butler.cc
parent9bfa07293928c371d59db2091ba2b7e715ce5994 (diff)
Replace aligned bool with enum Alignment.
Diffstat (limited to 'src/lib/butler.cc')
-rw-r--r--src/lib/butler.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/lib/butler.cc b/src/lib/butler.cc
index ca0887a4c..5a5cc4912 100644
--- a/src/lib/butler.cc
+++ b/src/lib/butler.cc
@@ -57,7 +57,7 @@ using namespace boost::placeholders;
/** @param pixel_format Pixel format functor that will be used when calling ::image on PlayerVideos coming out of this
* butler. This will be used (where possible) to prepare the PlayerVideos so that calling image() on them is quick.
* @param aligned Same as above for the `aligned' flag.
* @param fast Same as above for the `fast' flag.
*/
Butler::Butler (
@@ -67,7 +67,7 @@ Butler::Butler (
int audio_channels,
function<AVPixelFormat (AVPixelFormat)> pixel_format,
VideoRange video_range,
- bool aligned,
+ Image::Alignment alignment,
bool fast,
bool prepare_only_proxy
)
@@ -84,7 +84,7 @@ Butler::Butler (
, _disable_audio (false)
, _pixel_format (pixel_format)
, _video_range (video_range)
- , _aligned (aligned)
+ , _alignment (alignment)
, _fast (fast)
, _prepare_only_proxy (prepare_only_proxy)
{
@@ -325,7 +325,7 @@ try
/* If the weak_ptr cannot be locked the video obviously no longer requires any work */
if (video) {
LOG_TIMING("start-prepare in %1", thread_id());
- video->prepare (_pixel_format, _video_range, _aligned, _fast, _prepare_only_proxy);
+ video->prepare (_pixel_format, _video_range, _alignment, _fast, _prepare_only_proxy);
LOG_TIMING("finish-prepare in %1", thread_id());
}
}
@@ -57,7 +57,7 @@ using namespace boost::placeholders;
/** @param pixel_format Pixel format functor that will be used when calling ::image on PlayerVideos coming out of this
* butler. This will be used (where possible) to prepare the PlayerVideos so that calling image() on them is quick.
- * @param aligned Same as above for the `aligned' flag.
+ * @param alignment Same as above for the `alignment' value.
* @param fast Same as above for the `fast' flag.
*/